@@ -1,4 +1,6 @@
 
+# $rcs = ' $Id: Charset.pm,v 1.375 2004/10/24 18:03:22 Daddy Exp $ ' ;
+
 =head1 NAME
 
 I18N::Charset - IANA Character Set Registry names and Unicode::MapUTF8
@@ -74,7 +76,7 @@ use strict;
 #	Public Global Variables
 #-----------------------------------------------------------------------
 use vars qw( $VERSION @ISA @EXPORT @EXPORT_OK );
-$VERSION = '1.24';
+$VERSION = do { my @r = (q$Revision: 1.375 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 @ISA       = qw( Exporter );
 @EXPORT    = qw( iana_charset_name
 map8_charset_name
@@ -114,13 +116,12 @@ my %MIBtoUMU8;
 # %MIBtoLIBI is a hash of mib to libiconv names.  (Only valid for
 # those libiconv names that we can find in the IANA registry)
 my %MIBtoLIBI;
-# %MIBtoLIBI is a hash of mib to Encode names.  (Only valid for
+# %MIBtoENCO is a hash of mib to Encode names.  (Only valid for
 # those Encode names that we can find in the IANA registry)
 my %MIBtoENCO;
 
-my ($debug, $verbose);
-# $debug = 1;
-$verbose ||= $debug;
+use constant DEBUG => 0;
+use constant DEBUG_ENCO => 0;
 
 =head1 CONVERSION ROUTINES
 
@@ -156,55 +157,55 @@ sub iana_charset_name
   my $code = shift;
   return undef unless defined $code;
   return undef unless $code ne '';
-  # $debug = ($code =~ m!sjis!);
-  # print STDERR " + iana_charset_name($code)..." if $debug;
-  my $mib = &short_to_mib($code);
+  # $iDebug = ($code =~ m!sjis!);
+  # print STDERR " + iana_charset_name($code)..." if $iDebug;
+  my $mib = &_short_to_mib($code);
   return undef unless defined $mib;
-  # print STDERR " + mib is ($mib)..." if $debug;
+  # print STDERR " + mib is ($mib)..." if $iDebug;
   # Make sure this is really a IANA mib:
   return undef if &_is_dummy($mib);
-  # print STDERR " + is really iana..." if $debug;
+  # print STDERR " + is really iana..." if $iDebug;
   return $MIBtoLONG{$mib};
   } # iana_charset_name
 
 
-sub try_list
+sub _try_list
   {
   my $code = shift;
-  my @asTry = ($code, &strip($code));
-  push @asTry, &strip($code) if $code =~ s!\A(x-)+!!;  # try without leading x-
+  my @asTry = ($code, &_strip($code));
+  push @asTry, &_strip($code) if $code =~ s!\A(x-)+!!;  # try without leading x-
   return @asTry;
-  } # try_list
+  } # _try_list
 
-sub short_to_mib
+sub _short_to_mib
   {
   my $code = shift;
   local $^W = 0;
-  # print STDERR " + short_to_mib($code)..." if $debug;
+  # print STDERR " + _short_to_mib($code)..." if DEBUG;
   my $answer = undef;
  TRY_SHORT:
-  foreach my $sTry (&try_list($code))
+  foreach my $sTry (&_try_list($code))
     {
     my $iMIB = $SHORTtoMIB{$sTry} || 'undef';
-    # print STDERR "try($sTry)...$iMIB..." if $debug;
+    # print STDERR "try($sTry)...$iMIB..." if DEBUG;
     if ($iMIB ne 'undef')
       {
       $answer = $iMIB;
       last TRY_SHORT;
       } # if
     } # foreach
-  # print STDERR "answer is $answer\n" if $debug;
+  # print STDERR "answer is $answer\n" if DEBUG;
   return $answer;
-  } # short_to_mib
+  } # _short_to_mib
 
 
-sub short_to_long
+sub _short_to_long
   {
   local $^W = 0;
   my $s = shift;
-  # print STDERR " + short_to_long($s)..." if $debug;
-  return $MIBtoLONG{&short_to_mib($s)};
-  } # short_to_long
+  # print STDERR " + _short_to_long($s)..." if DEBUG;
+  return $MIBtoLONG{&_short_to_mib($s)};
+  } # _short_to_long
 
 
 =item mime_charset_name()
@@ -225,13 +226,13 @@ sub mime_charset_name
   my $code = shift;
   return undef unless defined $code;
   return undef unless $code ne '';
-  # print STDERR " + mime_charset_name($code)..." if $debug;
-  my $mib = &short_to_mib($code);
+  # print STDERR " + mime_charset_name($code)..." if DEBUG;
+  my $mib = &_short_to_mib($code);
   return undef unless defined $mib;
-  # print STDERR " + mib is ($mib)..." if $debug;
+  # print STDERR " + mib is ($mib)..." if DEBUG;
   # Make sure this is really an IANA mib:
   return undef if &_is_dummy($mib);
-  # print STDERR " + is really iana..." if $debug;
+  # print STDERR " + is really iana..." if DEBUG;
   return $MIBtoMIME{$mib};
   } # mime_charset_name
 
@@ -257,7 +258,11 @@ sub _maybe_load_enco # PRIVATE
   # Get a list of aliases from Encode:
   if (eval q{require Encode})
     {
-    my @as = Encode->encodings(':all');
+    my @as;
+    @as = Encode->encodings(':all');
+    # push @as, Encode->encodings('EBCDIC');
+    my $iFake = 0;
+    my $iReal = 0;
  ENCODING:
     foreach my $s (@as)
       {
@@ -268,18 +273,28 @@ sub _maybe_load_enco # PRIVATE
         {
         # Create a dummy mib:
         $mib = $sFakeMIB++;
+        $iFake++;
         } # if
       else
         {
         $mib = &charset_name_to_mib($sIana);
+        $iReal++;
         }
       # At this point we have a mib for this Encode entry.
       $MIBtoENCO{$mib} = $s;
-      # print STDERR " +   mib for enco ==$s== is $mib\n";
-      $SHORTtoMIB{&strip($s)} = $mib;
-      # print STDERR " +   assign enco =$s==>$mib\n" if &_is_dummy($mib);
+      DEBUG_ENCO && print STDERR " +   mib for enco ==$s== is $mib\n";
+      $SHORTtoMIB{&_strip($s)} = $mib;
+      DEBUG_ENCO && print STDERR " +   assign enco =$s==>$mib\n" if &_is_dummy($mib);
+      } # foreach ENCODING
+    if (DEBUG_ENCO)
+      {
+      print STDERR " + Summary of Encode encodings:\n";
+      printf STDERR (" +   %d encodings found.\n", scalar(@as));
+      print STDERR " +   $iFake fake mibs created.\n";
+      print STDERR " +   $iReal real mibs re-used.\n";
       } # if
     $iEncoLoaded = 1;
+    &add_enco_alias('Windows-31J', 'cp932');
     } # if
   else
     {
@@ -298,13 +313,14 @@ sub enco_charset_name
   my $code = shift;
   return undef unless defined $code;
   return undef unless $code ne '';
-  # my $debug = 1; # ($code =~ m!johab!i);
-  # print STDERR " + enco_charset_name($code)..." if $debug;
-  my $mib = &short_to_mib($code);
+  &_maybe_load_enco();
+  my $iDebug = 0; # ($code =~ m!johab!i);
+  print STDERR " + enco_charset_name($code)..." if ($iDebug || DEBUG_ENCO);
+  my $mib = &_short_to_mib($code);
   return undef unless defined $mib;
-  # print STDERR " + mib is ($mib)..." if $debug;
+  print STDERR " + mib is ($mib)..." if ($iDebug || DEBUG_ENCO);
   my $ret = &_mib_to_enco($mib);
-  # print STDERR " + enco is ($ret)..." if $debug;
+  print STDERR " + enco is ($ret)..." if ($iDebug || DEBUG_ENCO);
   return $ret;
   } # enco_charset_name
 
@@ -365,7 +381,7 @@ sub _maybe_load_libi # PRIVATE
           {
           $MIBtoLIBI{$mib} = $sWord;
           # print STDERR " +   mib for libi ==$sWord== is $mib\n";
-          $SHORTtoMIB{&strip($sWord)} = $mib;
+          $SHORTtoMIB{&_strip($sWord)} = $mib;
           } # foreach ADD_LIBI
         } # foreach ICONV_LINE
       } # if
@@ -384,13 +400,13 @@ sub libi_charset_name
   my $code = shift;
   return undef unless defined $code;
   return undef unless $code ne '';
-  # my $debug = 1; # ($code =~ m!johab!i);
-  # print STDERR " + libi_charset_name($code)..." if $debug;
-  my $mib = &short_to_mib($code);
+  # my $iDebug = 1; # ($code =~ m!johab!i);
+  # print STDERR " + libi_charset_name($code)..." if $iDebug;
+  my $mib = &_short_to_mib($code);
   return undef unless defined $mib;
-  # print STDERR " + mib is ($mib)..." if $debug;
+  # print STDERR " + mib is ($mib)..." if $iDebug;
   my $ret = &_mib_to_libi($mib);
-  # print STDERR " + libi is ($ret)..." if $debug;
+  # print STDERR " + libi is ($ret)..." if $iDebug;
   return $ret;
   } # libi_charset_name
 
@@ -465,18 +481,18 @@ sub map8_charset_name
   my $code = shift;
   return undef unless defined $code;
   return undef unless $code ne '';
-  # $debug = 0 && ($code =~ m!037!);
-  # print STDERR " + map8_charset_name($code)..." if $debug;
-  $code = &strip($code);
-  # print STDERR "$code..." if $debug;
-  my $iMIB = &short_to_mib($code) || 'undef';
-  # print STDERR "$iMIB..." if $debug;
+  # $iDebug = 0 && ($code =~ m!037!);
+  # print STDERR " + map8_charset_name($code)..." if $iDebug;
+  $code = &_strip($code);
+  # print STDERR "$code..." if $iDebug;
+  my $iMIB = &_short_to_mib($code) || 'undef';
+  # print STDERR "$iMIB..." if $iDebug;
   if ($iMIB ne 'undef')
     {
-    # print STDERR "$MIBtoMAP8{$iMIB}\n" if $debug;
+    # print STDERR "$MIBtoMAP8{$iMIB}\n" if $iDebug;
     return $MIBtoMAP8{$iMIB};
     } # if
-  # print STDERR "undef\n" if $debug;
+  # print STDERR "undef\n" if $iDebug;
   return undef;
   } # map8_charset_name
 
@@ -491,8 +507,6 @@ important.
 
     $sCharset = umap_charset_name('hebrew');
 
-=back
-
 =cut
 
 sub umap_charset_name
@@ -500,17 +514,17 @@ sub umap_charset_name
   my $code = shift;
   return undef unless defined $code;
   return undef unless $code ne '';
-  # $debug = ($code =~ m!apple!i);
-  # print STDERR "\n + MIBtoUMAP{dummymib029} == $MIBtoUMAP{$sDummy .'029'}\n\n" if $debug;
-  # print STDERR " + umap_charset_name($code)..." if $debug;
-  my $iMIB = &short_to_mib(&strip($code)) || 'undef';
-  # print STDERR "$iMIB..." if $debug;
+  # $iDebug = ($code =~ m!apple!i);
+  # print STDERR "\n + MIBtoUMAP{dummymib029} == $MIBtoUMAP{$sDummy .'029'}\n\n" if $iDebug;
+  # print STDERR " + umap_charset_name($code)..." if $iDebug;
+  my $iMIB = &_short_to_mib(&_strip($code)) || 'undef';
+  # print STDERR "$iMIB..." if $iDebug;
   if ($iMIB ne 'undef')
     {
-    # print STDERR "$MIBtoUMAP{$iMIB}\n" if $debug;
+    # print STDERR "$MIBtoUMAP{$iMIB}\n" if $iDebug;
     return $MIBtoUMAP{$iMIB};
     } # if
-  # print STDERR "undef\n" if $debug;
+  # print STDERR "undef\n" if $iDebug;
   return undef;
   } # umap_charset_name
 
@@ -533,19 +547,20 @@ sub umu8_charset_name
   my $code = shift;
   return undef unless defined $code;
   return undef unless $code ne '';
-  # $debug = ($code =~ m!u!);
-  # print STDERR " + umu8_charset_name($code)..." if $debug;
-  my $iMIB = &short_to_mib($code) || 'undef';
-  # print STDERR "$iMIB..." if $debug;
+  # $iDebug = ($code =~ m!u!);
+  # print STDERR " + umu8_charset_name($code)..." if $iDebug;
+  my $iMIB = &_short_to_mib($code) || 'undef';
+  # print STDERR "$iMIB..." if $iDebug;
   if ($iMIB ne 'undef')
     {
-    # print STDERR "$MIBtoUMU8{$iMIB}\n" if $debug;
+    # print STDERR "$MIBtoUMU8{$iMIB}\n" if $iDebug;
     return $MIBtoUMU8{$iMIB};
     } # if
-  # print STDERR "undef\n" if $debug;
+  # print STDERR "undef\n" if $iDebug;
   return undef;
   } # umu8_charset_name
 
+=back
 
 =head1 QUERY ROUTINES
 
@@ -604,15 +619,16 @@ name referred to by the existing alias 'sjis' (which happens to be 'Shift_JIS').
 sub add_iana_alias
   {
   my ($sAlias, $sReal) = @_;
-  # print STDERR " + add_iana_alias($sAlias,$sReal)...";
+  # print STDERR " + add_iana_alias($sAlias, $sReal)\n";
   my $sName = &iana_charset_name($sReal);
   if (not defined($sName))
     {
-    carp "attempt to alias \"$sAlias\" to unknown IANA character set \"$sReal\"\n" if $verbose;
+    carp qq{attempt to alias "$sAlias" to unknown IANA charset "$sReal"};
     return undef;
     } # if
-  # print STDERR "$sName...", &short_to_mib(&strip($sName)), "\n";
-  $SHORTtoMIB{&strip($sAlias)} = &short_to_mib(&strip($sName));
+  my $mib = &_short_to_mib(&_strip($sName));
+  # print STDERR " --> $sName --> $mib\n";
+  $SHORTtoMIB{&_strip($sAlias)} = $mib;
   return $sName;
   } # add_iana_alias
 
@@ -658,11 +674,11 @@ sub add_map8_alias
   {
   my ($sAlias, $sReal) = @_;
   my $sName = &map8_charset_name($sReal);
-  my $sShort = &strip($sAlias);
-  my $sShortName = &strip($sName);
+  my $sShort = &_strip($sAlias);
+  my $sShortName = &_strip($sName);
   if (not defined($sName))
     {
-    carp "attempt to alias \"$sAlias\" to unknown Map8 character set \"$sReal\"\n" if $verbose;
+    carp qq{attempt to alias "$sAlias" to unknown Map8 charset "$sReal"};
     return undef;
     } # if
   if (exists $SHORTtoMIB{$sShortName})
@@ -685,11 +701,11 @@ sub add_umap_alias
   {
   my ($sAlias, $sReal) = @_;
   my $sName = &umap_charset_name($sReal);
-  my $sShort = &strip($sAlias);
-  my $sShortName = &strip($sName);
+  my $sShort = &_strip($sAlias);
+  my $sShortName = &_strip($sName);
   if (not defined($sName))
     {
-    carp "attempt to alias \"$sAlias\" to unknown U::Map character set \"$sReal\"\n" if $verbose;
+    carp qq{attempt to alias "$sAlias" to unknown U::Map charset "$sReal"};
     return undef;
     } # if
   if (exists $SHORTtoMIB{$sShortName})
@@ -733,12 +749,12 @@ sub add_libi_alias
   my $sName = &libi_charset_name($sReal);
   if (not defined($sName))
     {
-    carp "attempt to alias \"$sAlias\" to unknown iconv conversion scheme \"$sReal\"\n" if $verbose;
+    carp qq{attempt to alias "$sAlias" to unknown iconv charset "$sReal"};
     return undef;
     } # if
-  my $mib = &short_to_mib(&strip($sName));
+  my $mib = &_short_to_mib(&_strip($sName));
   # print STDERR "sName=$sName...mib=$mib\n";
-  $SHORTtoMIB{&strip($sAlias)} = $mib;
+  $SHORTtoMIB{&_strip($sAlias)} = $mib;
   return $sName;
   } # add_libi_alias
 
@@ -772,22 +788,23 @@ referred to by the existing alias 'my-japanese1' (which happens to be
 sub add_enco_alias
   {
   my ($sAlias, $sReal) = @_;
-  # print STDERR " + add_enco_alias($sAlias,$sReal)...";
+  my $iDebug = 0;
+  print STDERR " + add_enco_alias($sAlias,$sReal)..." if ($iDebug || DEBUG_ENCO);
   my $sName = &enco_charset_name($sReal);
   if (not defined($sName))
     {
-    carp "attempt to alias \"$sAlias\" to unknown iconv conversion scheme \"$sReal\"\n" if $verbose;
+    carp qq{attempt to alias "$sAlias" to unknown Encode charset "$sReal"};
     return undef;
     } # if
-  my $mib = &short_to_mib(&strip($sName));
-  # print STDERR "sName=$sName...mib=$mib\n";
-  $SHORTtoMIB{&strip($sAlias)} = $mib;
+  my $mib = &_short_to_mib(&_strip($sName));
+  print STDERR "sName=$sName...mib=$mib\n" if ($iDebug || DEBUG_ENCO);
+  $SHORTtoMIB{&_strip($sAlias)} = $mib;
   return $sName;
   } # add_enco_alias
 
 #-----------------------------------------------------------------------
 
-=head1 EXAMPLES
+=back
 
 =head1 KNOWN BUGS AND LIMITATIONS
 
@@ -857,12 +874,12 @@ modify it under the same terms as Perl itself.
 
 #-----------------------------------------------------------------------
 
-sub strip
+sub _strip
   {
   my $s = lc(shift);
   $s =~ tr/[0-9a-zA-Z]//dc;
   return $s;
-  } # strip
+  } # _strip
 
 # initialization code - stuff the DATA into some data structure
 
@@ -872,6 +889,7 @@ INFINITE:
 while (1)
   {
   my ($sName, $iMIB, $sAlias, $mimename);
+  my $iDebug = 0;
   # I used to use the __DATA__ mechanism to initialize the data, but
   # that is not compatible with perlapp
   my $io = new IO::String(_init_data());
@@ -883,10 +901,9 @@ while (1)
       {
       # Blank line separates entries.
       ($sName, $iMIB, $sAlias, $mimename) = ('', '', '', 0);
-      $debug = 0;
       next DATA;
       } # unless
-    # print STDERR " + read DATA $_" if $debug;
+    # print STDERR " + read DATA $_" if $iDebug;
 
     # If this line indicates the MIME name, remember this fact; but if
     # it doesn't, keep the previous setting (in case the MIME name is
@@ -895,20 +912,20 @@ while (1)
     if ($sLine =~ m/^Name:\s*(\S+)/)
       {
       $sName = $1;
-      # $debug = ($sName =~ m!1252!i);
-      print STDERR " +   read Name: $sName\n" if $debug;
+      # $iDebug = ($sName =~ m!1252!i);
+      print STDERR " +   read Name: $sName\n" if $iDebug;
       } # if Name
     elsif ($sLine =~ m!^MIBenum:\s*(\d+)!)
       {
       $iMIB = $1;
-      # $debug = ($iMIB =~ m!225[23]!);
-      print STDERR " +   found mib: $iMIB, long = $sName\n" if $debug;
+      # $iDebug = ($iMIB =~ m!225[23]!);
+      print STDERR " +   found mib: $iMIB, long = $sName\n" if $iDebug;
       $MIBtoLONG{$iMIB} = $sName;
       $LONGtoMIB{$sName} = $iMIB;
-      $SHORTtoMIB{&strip($sName)} = $iMIB;
+      $SHORTtoMIB{&_strip($sName)} = $iMIB;
       if ($mimename)
         {
-        print STDERR " +   found mime: mib=$iMIB, mime=$sName\n" if $debug;
+        print STDERR " +   found mime: mib=$iMIB, mime=$sName\n" if $iDebug;
 	$MIBtoMIME{$iMIB} = $sName;
         # We've got the MIME name for this entry, don't look for more
         # until next entry:
@@ -920,11 +937,11 @@ while (1)
       $sAlias = $1;
       if ($sAlias !~ m!None!i)
         {
-        print STDERR " +   map Alias ($sAlias) to mib $iMIB\n" if $debug;
-        $SHORTtoMIB{&strip($sAlias)} = $iMIB;
+        print STDERR " +   map Alias ($sAlias) to mib $iMIB\n" if $iDebug;
+        $SHORTtoMIB{&_strip($sAlias)} = $iMIB;
 	if ($mimename)
 	  {
-          print STDERR " +   found mime: mib=$iMIB, mime=$sAlias\n" if $debug;
+          print STDERR " +   found mime: mib=$iMIB, mime=$sAlias\n" if $iDebug;
 	  $MIBtoMIME{$iMIB} = $sAlias;
           # We've got the MIME name for this entry, don't look for
           # more until next entry:
@@ -943,13 +960,14 @@ while (1)
  EQUAL_LINE:
   foreach my $sLine (@asEqualLines)
     {
+    next if ($sLine =~ m!\A#!);
     # print STDERR " +   equal-sign line $sLine...\n";
     my @as = split(/\ ===\ /, $sLine);
     next unless defined $as[0];
     next unless $as[0] ne '';
     next unless defined $as[1];
     next unless $as[1] ne '';
-    my $iMIB = $SHORTtoMIB{&strip($as[0])} || '';
+    my $iMIB = $SHORTtoMIB{&_strip($as[0])} || '';
     unless ($iMIB ne '')
       {
       print STDERR " --- can not find IANA entry for equal-sign directive $as[0]\n";
@@ -957,7 +975,7 @@ while (1)
       } # unless
     foreach my $s (@as)
       {
-      my $sStrip = &strip($s);
+      my $sStrip = &_strip($s);
       # print STDERR " +     $sStrip --> $iMIB\n";
       $SHORTtoMIB{$sStrip} = $iMIB;
       } # foreach
@@ -967,14 +985,14 @@ while (1)
 
   if (eval "require Unicode::Map8")
     {
-    # $debug = 1;
-    print STDERR " + found Unicode::Map8 installed, will build map8 tables..." if $debug;
+    # $iDebug = 1;
+    print STDERR " + found Unicode::Map8 installed, will build map8 tables..." if $iDebug;
     my $sMapFile = "$Unicode::Map8::MAPS_DIR/aliases";
     if (open MAPS, $sMapFile)
       {
       while (defined (my $sLine = <MAPS>))
         {
-        # $debug = ($sLine =~ m!866!);
+        # $iDebug = ($sLine =~ m!866!);
         my @as = split(/\s/, $sLine);
         my $sFound = '';
         my $iMIB = '';
@@ -984,7 +1002,7 @@ while (1)
  MAP8ITEM:
         foreach my $s ($sMap8, @as)
           {
-          print STDERR " +      looking for $s in iana table...\n" if $debug;
+          print STDERR " +      looking for $s in iana table...\n" if $iDebug;
           if (defined (my $sTemp = &iana_charset_name($s)))
             {
             $sFound = $sTemp;
@@ -993,46 +1011,46 @@ while (1)
           } # foreach
         if ($sFound eq '')
           {
-          # $debug = 1;
+          # $iDebug = 1;
           $iMIB = $sFakeMIB++;
-          print STDERR " +   had to use a dummy mib ($iMIB) for U::Map8==$sMap8==\n" if $debug;
+          print STDERR " +   had to use a dummy mib ($iMIB) for U::Map8==$sMap8==\n" if $iDebug;
           $LONGtoMIB{$sMap8} = $iMIB;
           } # unless
         else
           {
           $iMIB = $LONGtoMIB{$sFound};
-          print STDERR " +   found IANA name $sFound ($iMIB) for Map8 entry $sMap8\n" if $debug;
+          print STDERR " +   found IANA name $sFound ($iMIB) for Map8 entry $sMap8\n" if $iDebug;
           }
-        # $debug = ($iMIB =~ m!225[23]!);
+        # $iDebug = ($iMIB =~ m!225[23]!);
         # Make this IANA mib map to this Map8 name:
-        print STDERR " +      map $iMIB to $sMap8 in MIBtoMAP8...\n" if $debug;
+        print STDERR " +      map $iMIB to $sMap8 in MIBtoMAP8...\n" if $iDebug;
         $MIBtoMAP8{$iMIB} = $sMap8;
         # Map ALL the Map8 aliases to this Map8 master name:
         foreach my $s ($sMap8, @as)
           {
-          $s = &strip($s);
-          print STDERR " +      map $s to $iMIB in SHORTtoMIB...\n" if $debug;
+          $s = &_strip($s);
+          print STDERR " +      map $s to $iMIB in SHORTtoMIB...\n" if $iDebug;
           $SHORTtoMIB{$s} = $iMIB;
           } # foreach
-        # $debug = 0;
+        # $iDebug = 0;
         } # while
       close MAPS;
       } # if open
     else
       {
-      carp " --- couldn't open $sMapFile for read" if $verbose;
+      carp " --- couldn't open $sMapFile for read" if $iDebug;
       }
     # If there are special cases for Unicode::Map8, add them here:
     # &add_map8_alias("new-name", "existing-name");
-    print STDERR "done.\n" if $debug;
+    print STDERR "done.\n" if $iDebug;
     } # if Unicode::Map8 installed
 
   # last INFINITE;
 
-  # $debug = 1;
+  # $iDebug = 1;
   if (eval "require Unicode::Map")
     {
-    print STDERR " + found Unicode::Map installed, will build tables..." if $debug;
+    print STDERR " + found Unicode::Map installed, will build tables..." if $iDebug;
     my $MAP_Path = $INC{'Unicode/Map.pm'};
     $MAP_Path =~ s/\.pm//;
     my $sMapFile = "$MAP_Path/REGISTRY";
@@ -1043,14 +1061,14 @@ while (1)
       my @asMAPS = split(/\n\s*\n/, <MAPS>);
       foreach my $sEntry (@asMAPS)
         {
-        $debug = 0;
+        $iDebug = 0;
         # print STDERR " + working on Umap entry >>>>>$sEntry<<<<<...\n";
         my ($sName, $iMIB) = ('', '');
         # Get the value of the name field, and skip entries with no name:
         next unless $sEntry =~ m!^name:\s+(\S+)!mi;
         $sName = $1;
-        # $debug = ($sName =~ m!apple!);
-        print STDERR " +   UMAP sName is $sName\n" if $debug;
+        # $iDebug = ($sName =~ m!apple!);
+        print STDERR " +   UMAP sName is $sName\n" if $iDebug;
         my @asAlias = split /\n/, $sEntry;
         @asAlias = map { /alias:\s+(.*)/; $1 } (grep /alias/, @asAlias);
         # See if this entry already has the MIB identified:
@@ -1065,11 +1083,11 @@ while (1)
  ALIAS:
           foreach my $sAlias ($sName, @asAlias)
             {
-            print STDERR " +     try alias $sAlias\n" if $debug;
-            my $iMIBtry = &short_to_mib(&strip($sAlias));
+            print STDERR " +     try alias $sAlias\n" if $iDebug;
+            my $iMIBtry = &_short_to_mib(&_strip($sAlias));
             if ($iMIBtry)
               {
-              print STDERR " +       matched\n" if $debug;
+              print STDERR " +       matched\n" if $iDebug;
               $iMIB = $iMIBtry;
               last ALIAS;
               } # if
@@ -1078,21 +1096,21 @@ while (1)
           if ($iMIB eq '')
             {
             $iMIB = $sFakeMIB++;
-            print STDERR " +   had to use a dummy mib ($iMIB) for U::Map==$sName==\n" if $debug;
+            print STDERR " +   had to use a dummy mib ($iMIB) for U::Map==$sName==\n" if $iDebug;
             } # if
           } # else
-        # $debug = ($iMIB =~ m!225[23]!);
-        # $debug = ($iMIB eq '17');
-        print STDERR " +   UMAP mib is $iMIB\n" if $debug;
+        # $iDebug = ($iMIB =~ m!225[23]!);
+        # $iDebug = ($iMIB eq '17');
+        print STDERR " +   UMAP mib is $iMIB\n" if $iDebug;
         $MIBtoUMAP{$iMIB} = $sName;
         # Set the long IANA name, IF it is empty so far:
         $MIBtoLONG{$iMIB} ||= $sName;
         $LONGtoMIB{$sName} ||= $iMIB;
-        $SHORTtoMIB{&strip($sName)} ||= $iMIB;
+        $SHORTtoMIB{&_strip($sName)} ||= $iMIB;
         foreach my $sAlias (@asAlias)
           {
-          print STDERR " +   UMAP alias $sAlias\n" if $debug;
-          $SHORTtoMIB{&strip($sAlias)} = $iMIB;
+          print STDERR " +   UMAP alias $sAlias\n" if $iDebug;
+          $SHORTtoMIB{&_strip($sAlias)} = $iMIB;
           } # while
         } # foreach
       close MAPS;
@@ -1100,55 +1118,55 @@ while (1)
       } # if open
     else
       {
-      carp " --- couldn't open $sMapFile for read" if $verbose;
+      carp " --- couldn't open $sMapFile for read" if $iDebug;
       }
     # If there are special cases for Unicode::Map, add them here:
     # &add_umap_alias("new-name", "existing-name");
-    print STDERR "done.\n" if $debug;
+    print STDERR "done.\n" if $iDebug;
     } # if Unicode::Map installed
 
   # Make sure to do U::MapUTF8 last, because it (in turn) depends on
   # the others.
-  # $debug = 1;
+  # $iDebug = 1;
   if (1.0 <= (eval q{ require Unicode::MapUTF8; $Unicode::MapUTF8::VERSION } || 0))
     {
-    print STDERR " + found Unicode::MapUTF8 $Unicode::MapUTF8::VERSION installed, will build tables...\n" if $debug;
+    print STDERR " + found Unicode::MapUTF8 $Unicode::MapUTF8::VERSION installed, will build tables...\n" if $iDebug;
     my @as;
     # Wrap this in an eval to avoid compiler warning(?):
     eval { @as = &Unicode::MapUTF8::utf8_supported_charset() };
 UMU8_NAME:
     foreach my $sName (@as)
       {
-      # $debug = ($sName =~ m!jis!i);
-      print STDERR " + working on UmapUTF8 entry >>>>>$sName<<<<<...\n" if $debug;
+      # $iDebug = ($sName =~ m!jis!i);
+      print STDERR " + working on UmapUTF8 entry >>>>>$sName<<<<<...\n" if $iDebug;
       my $s = iana_charset_name($sName) || '';
       if ($s ne '')
         {
-        # print STDERR " +   iana name is >>>>>$s<<<<<...\n" if $debug;
+        # print STDERR " +   iana name is >>>>>$s<<<<<...\n" if $iDebug;
         $MIBtoUMU8{charset_name_to_mib($s)} = $sName;
         next UMU8_NAME;
         } # if already maps to IANA
-      # print STDERR " +   UmapUTF8 entry ===$sName=== has no iana entry\n" if $debug;
+      # print STDERR " +   UmapUTF8 entry ===$sName=== has no iana entry\n" if $iDebug;
       $s = umap_charset_name($sName) || '';
       if ($s ne '')
         {
-        print STDERR " +   U::Map name is >>>>>$s<<<<<...\n" if $debug;
+        print STDERR " +   U::Map name is >>>>>$s<<<<<...\n" if $iDebug;
         $MIBtoUMU8{charset_name_to_mib($s)} = $sName;
         next UMU8_NAME;
         } # if maps to U::Map
-      # print STDERR " +   UmapUTF8 entry ===$sName=== has no U::Map entry\n" if $debug;
+      # print STDERR " +   UmapUTF8 entry ===$sName=== has no U::Map entry\n" if $iDebug;
       $s = map8_charset_name($sName) || '';
       if ($s ne '')
         {
-        print STDERR " +   U::Map8 name is >>>>>$s<<<<<...\n" if $debug;
+        print STDERR " +   U::Map8 name is >>>>>$s<<<<<...\n" if $iDebug;
         $MIBtoUMU8{charset_name_to_mib($s)} = $sName;
         next UMU8_NAME;
         } # if maps to U::Map8
-      print STDERR " +   UmapUTF8 entry ===$sName=== has no entries at all\n" if $debug;
+      print STDERR " +   UmapUTF8 entry ===$sName=== has no entries at all\n" if $iDebug;
       } # foreach
     # If there are special cases for Unicode::MapUTF8, add them here:
     # &add_umap_alias("new-name", "existing-name");
-    print STDERR "done.\n" if $debug;
+    print STDERR "done.\n" if $iDebug;
     } # if Unicode::MapUTF8 installed
 
   last INFINITE;
@@ -1184,18 +1202,18 @@ UMU8_NAME:
   last INFINITE;
 
   # debugging: huge dump:
-  # &dumpHash('MIBtoLONG', \%MIBtoLONG);
-  # &dumpHash('LONGtoMIB', \%LONGtoMIB);
-  # &dumpHash('SHORTtoMIB', \%SHORTtoMIB);
+  # &_dump_hash('MIBtoLONG', \%MIBtoLONG);
+  # &_dump_hash('LONGtoMIB', \%LONGtoMIB);
+  # &_dump_hash('SHORTtoMIB', \%SHORTtoMIB);
   foreach (keys %SHORTtoMIB)
     {
-    print STDERR " + short_to_long($_) == ", &short_to_long($_) || 'undef', "\n";
+    print STDERR " + _short_to_long($_) == ", &_short_to_long($_) || 'undef', "\n";
     } # foreach
 
   last INFINITE;
   } # while
 
-sub dumpHash
+sub _dump_hash
   {
   my ($sName, $rh) = @_;
   print STDERR " + after initialization, $sName is:\n";
@@ -1203,7 +1221,7 @@ sub dumpHash
     {
     print STDERR " +   $key => $$rh{$key}\n";
     } # foreach
-  } # dumpHash
+  } # _dump_hash
 
 sub _init_data_extra
   {
@@ -1230,15 +1248,14 @@ EBCDIC-ES === ebcdic-cp-es
 EBCDIC-FR === ebcdic-cp-fr
 EBCDIC-IT === ebcdic-cp-it
 EBCDIC-UK === ebcdic-cp-gb
-EBCDIC-US === ebcdic-cp-us
 EBCDIC-FI-SE === ebcdic-cp-fi
 UTF-7 === Unicode-2-0-utf-7
 UTF-8 === Unicode-2-0-utf-8
 Extended_UNIX_Code_Packed_Format_for_Japanese === euc === euc-jp
-# These were added for Unicode::MapUTF8:
+# These are for Unicode::MapUTF8:
 ISO-10646-UCS-2 === ucs2
 ISO-10646-UCS-4 === ucs4
-# These were added for iconv:
+# These are for iconv:
 ISO-2022-JP === ISO-2022-JP-1
 # These are for Encode:
 IBM1047 === cp1047
@@ -1248,6 +1265,37 @@ JIS_X0201 === jis0201-raw
 JIS_C6226-1983 === jis0208-raw
 JIS_X0212-1990 === jis0212-raw
 KS_C_5601-1987 === ksc5601-raw
+CP037 === CP37
+cp863 === DOSCanadaF
+cp860 === DOSPortuguese
+cp869 === DOSGreek2
+koi8-r === cp878
+# These encodings are handled by Encode, but I don't know what they are:
+# ??? === AdobeZdingbats
+# ??? === MacArabic
+# ??? === MacCentralEurRoman
+# ??? === MacChineseSimp
+# ??? === MacChineseTrad
+# ??? === MacCroatian
+# ??? === MacCyrillic
+# ??? === MacDingbats
+# ??? === MacFarsi
+# ??? === MacGreek
+# ??? === MacHebrew
+# ??? === MacIcelandic
+# ??? === MacJapanese
+# ??? === MacKorean
+# ??? === MacRomanian
+# ??? === MacRumanian
+# ??? === MacSami
+# ??? === MacThai
+# ??? === MacTurkish
+# ??? === MacUkrainian
+# ??? === MacVietnamese
+# ??? === cp1006
+# ??? === dingbats
+# ??? === nextstep
+# ??? === posix-bc
 XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX
   } # _init_data_extra
 
@@ -1260,7 +1308,7 @@ sub _init_data
 ===================================================================
 CHARACTER SETS
 
-(last updated 2002-09-30)
+(last updated 2004-02-06)
 
 These are the official names for character sets that may be used in
 the Internet and may be referred to in Internet documentation.  These
@@ -1766,10 +1814,12 @@ Alias: latin4
 Alias: l4
 Alias: csISOLatin4
 
-Name: ECMA-cyrillic                                      [RFC1345,KXS2]
+Name: ECMA-cyrillic                                     
 MIBenum: 77
-Source: ECMA registry
+Source: ISO registry (formerly ECMA registry)
+         http://www.itscj.ipsj.jp/ISO-IR/111.pdf
 Alias: iso-ir-111
+Alias: KOI8-E
 Alias: csISO111ECMACyrillic
 
 Name: CSA_Z243.4-1985-1                                  [RFC1345,KXS2]
@@ -2555,6 +2605,20 @@ Alias: PT154
 Alias: CP154
 Alias: Cyrillic-Asian
 
+Name:  Amiga-1251
+MIBenum:  2104
+Source:  See (http://www.amiga.ultranet.ru/Amiga-1251.html)
+Alias:  Ami1251
+Alias:  Amiga1251
+Alias:  Ami-1251
+(Aliases are provided for historical reasons and should not be used)
+                                                              [Malyshev]
+															  
+Name:  KOI7-switched
+MIBenum:  2105
+Source:  See <http://www.iana.org/assignments/charset-reg/KOI7-switched>
+Aliases:  None
+
 Name: UNICODE-1-1                                              [RFC1641]
 MIBenum: 1010
 Source: RFC 1641
@@ -2615,9 +2679,9 @@ MIBenum: 103
 Source: RFC 1642
 Alias: csUnicode11UTF7
 
-Name: UTF-8                                                    [RFC2279]
+Name: UTF-8                                                    [RFC3629]
 MIBenum: 106
-Source: RFC 2279
+Source: RFC 3629
 Alias: None 
 
 Name: ISO-8859-13
@@ -2665,6 +2729,24 @@ Source: Chinese IT Standardization Technical Committee
         Please see: <http://www.iana.org/assignments/charset-reg/GB18030>
 Alias: None
 
+Name:  OSD_EBCDIC_DF04_15
+MIBenum:  115
+Source:  Fujitsu-Siemens standard mainframe EBCDIC encoding
+         Please see: <http://www.iana.org/assignments/charset-reg/OSD-EBCDIC-DF04-15>
+Alias:   None
+
+Name:  OSD_EBCDIC_DF03_IRV
+MIBenum:  116
+Source:  Fujitsu-Siemens standard mainframe EBCDIC encoding
+         Please see: <http://www.iana.org/assignments/charset-reg/OSD-EBCDIC-DF03-IRV>
+Alias:  None
+
+Name:  OSD_EBCDIC_DF04_1
+MIBenum:  117
+Source:  Fujitsu-Siemens standard mainframe EBCDIC encoding
+         Please see: <http://www.iana.org/assignments/charset-reg/OSD-EBCDIC-DF04-1>
+Alias:  None   
+
 Name: JIS_Encoding
 MIBenum: 16
 Source: JIS X 0202-1991.  Uses ISO 2022 escape sequences to
@@ -3033,6 +3115,8 @@ REFERENCES
 [RFC2781]  Hoffman, P., Yergeau, F., "UTF-16, an encoding of ISO 10646",
            RFC 2781, February 2000.
 
+[RFC3629]  Yergeau, F., "UTF-8, a transformation format of ISO 10646",
+           RFC3629, November 2003.
 
 PEOPLE
 ------
@@ -3047,6 +3131,8 @@ PEOPLE
 
 [Mahdi] Tamer Mahdi, <tamer@ca.ibm.com>, August 2000.
 
+[Malyshev] Michael Malyshev, <michael_malyshev@mail.ru>, January 2004
+
 [Murai] Jun Murai <jun@wide.ad.jp>
 
 [Nussbacher] Hank Nussbacher, <hank@vm.tau.ac.il>
@@ -3082,8 +3168,6 @@ PEOPLE
 
 
 
-
-
 EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
   } # _init_data
 
